<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 * @return array An array of default values
 */

if( !function_exists( 'edumag_pro_get_default_theme_options' ) ) :
	function edumag_pro_get_default_theme_options() {
		$theme_data = wp_get_theme();
		$edumag_pro_default_options = array(

			/*
			 * Homepage sections options
			 */

			// Featured Category
			'featured_category_enable'		=> 'static-frontpage',
			'featured_category_content_type'=> 'demo',

			// Popular Articles
			'popular_articles_enable' 		=> 'static-frontpage',
			'popular_articles_content_type' => 'demo',
			'popular_articles_title'		=> esc_html__( 'Popular Articles', 'edumag-pro' ),
			'popular_articles_subtitle'     => esc_html__( 'Find the most educational and motivating articles.', 'edumag-pro' ),
			'popular_articles_no_of_tabs'   => 3,

			'popular_articles_ad_type' 		=> 'demo',
			'popular_articles_ad_image'		=> get_template_directory_uri().'/assets/uploads/google-ad-1.jpg',
			'popular_articles_new_tab' 		=> true,

			// Search section
			'search_section_enable'			=> 'static-frontpage',
			'search_section_title'			=> esc_html__( 'Make Your Success A Priority.', 'edumag-pro' ),
			'search_section_subtitle'		=> esc_html__( 'Begin your Educational Journey Today.', 'edumag-pro' ),
			'search_section_background_image' => get_template_directory_uri() . '/assets/uploads/success.jpg',

			'search_section_search_in'		=> 'all',
			'search_section_button_text'    => esc_html__( 'Find College', 'edumag-pro' ),

			// Trending section
			'trending_section_enable'		=> 'static-frontpage',
			'trending_section_title'		=> esc_html__( 'Trending Courses', 'edumag-pro' ),
			'trending_section_subtitle'		=> esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'edumag-pro' ),
			'trending_section_content_type' => 'demo',
			'trending_section_count'		=> 5,
			'trending_section_enable_subscription'   => true,
			'trending_section_subscription_title'    => esc_html__( 'upcoming courses', 'edumag-pro' ),
			'trending_section_subscription_subtitle' => esc_html__( 'Donec feugiat ultricies accumsan. Fusce sed tempor.', 'edumag-pro' ),
			'trending_section_subscription_button'   => esc_html__( 'Get notified', 'edumag-pro' ),

			// Advertisement section
			'advertisement_section_enable'  => 'static-frontpage',
			'advertisement_section_ad_type'	=> 'demo',
			'advertisement_section_ad_image'=> get_template_directory_uri() . '/assets/uploads/google-ad-3.jpg',
			'advertisement_section_new_tab'	=> true,

			// latest news
			'latest_news_enable'			=> 'static-frontpage',
			'latest_news_content_type' 		=> 'demo',
			'latest_news_title' 			=> esc_html__( 'Latest News', 'edumag-pro' ),
			'latest_news_subtitle'			=> esc_html__( 'Find whats is going on in every educational sector.', 'edumag-pro' ),
			'latest_news_custom_post'       => class_exists( 'TP_Education' ) ? 'tp-class' : '',

			// Blog Sections
			'blogs_section_enable'			=> 'static-frontpage',
			'blogs_section_content_type'	=> 'demo',

			/*
			 * Custom page template
			 */
			'enable_map_section'			=> true,
			'map_type_option'				=> 'shortcode',
			'enable_contact_form'			=> true,

			/*
			 * Theme Options
			 */
			'enable_top_header' 			=> true,
			'enable_address_block'			=> true,
			'contact_phone_icon'			=> 'fa-phone',
			'contact_phone_number'			=> '9841334732',
			'contact_email_icon'			=> 'fa-envelope',
			'contact_email'					=> 'info@themepalace.com',
			'skype_icon'					=> 'fa-skype',
			'skype_link'					=> 'themepalace',
			'enable_social_link_block'		=> true,
			'no_of_social_link'				=> 3,
			'enable_custom_link_block'		=> true,
			'no_of_custom_link'				=> 2,

			'header_typography' 			=> 'default',
			'body_typography'				=> 'default',
			'theme_color'					=> 'blue',
			'loader_enable'         		=> false,
			'loader_icon'         			=> 'fa-spinner',
			'site_layout'         			=> 'wide',
			'sidebar_position'         		=> 'right-sidebar',
			'long_excerpt_length'           => 25,
			'short_excerpt_length'          => 10,
			'read_more_text'		        => esc_html__( 'Read More >>', 'edumag-pro' ),
			'breadcrumb_enable'         	=> true,
			'pagination_enable'         	=> true,
			'pagination_type'         		=> 'default',
			'copyright_text'           		=> sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'edumag-pro' ), '[the-year]', '[site-link]' ) . ' &#124; ' . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . __( 'by', 'edumag-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
			'scroll_top_visible'        	=> true,
			'reset_options'      			=> false,
			'enable_frontpage_content' 		=> true,
			'append_search'					=> true,
			'animation_enable'				=> false,

		);

		$output = apply_filters( 'edumag_pro_default_theme_options', $edumag_pro_default_options );
		// Sort array in ascending order, according to the key:
		if ( ! empty( $output ) ) {
			ksort( $output );
		}

		return $output;
	}
endif;