<?php
/**
 * EduMag Pro advertisement section Customizer options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

// Add popular articles enable section
$wp_customize->add_section( 'edumag_pro_advertisement_section', array(
  'title'             => esc_html__('Advertisement section','edumag-pro'),
  'description'       => esc_html__( 'Advertisement section options.', 'edumag-pro' ),
  'panel'             => 'edumag_pro_sections_panel'
) );

// Add advertisement section enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[advertisement_section_enable]', array(
  'default'           => $options['advertisement_section_enable'],
  'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[advertisement_section_enable]', array(
  'label'             => esc_html__( 'Enable on', 'edumag-pro' ),
  'section'           => 'edumag_pro_advertisement_section',
  'type'              => 'select',
  'choices'           => edumag_pro_enable_disable_options()
) );

// Add Popular articles advertisement title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[advertisement_section_customizer_title]', array(
  'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Edumag_Pro_Note_Control( $wp_customize, 'edumag_pro_theme_options[advertisement_section_customizer_title]', array(
  'label'             => esc_html__( 'Advertisement Section', 'edumag-pro' ),
  'section'           => 'edumag_pro_advertisement_section',
  'type'              => 'description',
  'active_callback'   => 'edumag_pro_is_advertisement_section_active',
) ) );

// Add advertisement section setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[advertisement_section_ad_type]', array(
  'default'           => $options['advertisement_section_ad_type'],
  'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[advertisement_section_ad_type]', array(
    'label'             => esc_html__( 'Advertisement Type', 'edumag-pro' ),
    'section'           => 'edumag_pro_advertisement_section',
    'type'              => 'select',
    'choices'           => array(
        'demo'          => esc_html__( 'Demo', 'edumag-pro' ),
        'ad_image'      => esc_html__( 'Advertisement Image', 'edumag-pro' ),
        'ad_code'       => esc_html__( 'Advertisement Code', 'edumag-pro' ),
    ),
    'active_callback'   => 'edumag_pro_is_advertisement_section_active',

) );

// Add advertisement image setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[advertisement_section_ad_image]', array(
  'default'           => $options['advertisement_section_ad_image'],
  'sanitize_callback' => 'edumag_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'edumag_pro_theme_options[advertisement_section_ad_image]',
    array(
        'label'           => esc_html__( 'Upload a Advertisement Image', 'edumag-pro' ),
        'description'     => esc_html__( 'Recommended advertisement image size is 1180x200 px', 'edumag-pro' ),
        'section'         => 'edumag_pro_advertisement_section',
        'active_callback' => 'edumag_pro_is_advertisement_section_ad_image_active',
    )
));

// Add advertisement link setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[advertisement_section_ad_url]', array(
  'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[advertisement_section_ad_url]', array(
  'label'             => esc_html__( 'Link', 'edumag-pro' ),
  'section'           => 'edumag_pro_advertisement_section',
  'type'              => 'url',
  'active_callback'   => 'edumag_pro_is_advertisement_section_ad_image_active',
) );

// Add advertisement open in new tab setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[advertisement_section_new_tab]', array(
  'sanitize_callback' => 'edumag_pro_sanitize_checkbox',
  'default'           => $options['advertisement_section_new_tab'],
) );

$wp_customize->add_control( 'edumag_pro_theme_options[advertisement_section_new_tab]', array(
  'label'             => esc_html__( 'Check to open in new tab.', 'edumag-pro' ),
  'section'           => 'edumag_pro_advertisement_section',
  'type'              => 'checkbox',
  'active_callback'   => 'edumag_pro_is_advertisement_section_ad_image_active',
) );

// Add advertisement image setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[advertisement_section_ad_code]', array(
  'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[advertisement_section_ad_code]',
    array(
    'label'           => esc_html__( 'Advertisement Code', 'edumag-pro' ),
    'description'     => esc_html__( 'Enter advertisement code.', 'edumag-pro' ),
    'section'         => 'edumag_pro_advertisement_section',
    'type'            => 'textarea',
    'active_callback' => 'edumag_pro_is_advertisement_section_ad_code_active',
   )
);

