<?php
/**
 * EduMag Pro Popular Articles Customizer options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

// Add popular articles enable section
$wp_customize->add_section( 'edumag_pro_popular_articles_section', array(
	'title'             => esc_html__( 'Popular Articles','edumag-pro'),
	'description'       => esc_html__( 'Popular Articles section options.', 'edumag-pro' ),
	'panel'             => 'edumag_pro_sections_panel'
) );

// Add category blog enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_enable]', array(
	'default'           => $options['popular_articles_enable'],
	'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_enable]', array(
	'label'             => esc_html__( 'Enable on', 'edumag-pro' ),
	'section'           => 'edumag_pro_popular_articles_section',
	'type'              => 'select',
	'choices'           => edumag_pro_enable_disable_options()
) );

// Add Popular articles content type setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_content_type]', array(
	'default'           => $options['popular_articles_content_type'],
	'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'edumag_pro_is_popular_articles_section_active',
	'choices'         	=> array(
		'demo'     => esc_html__( 'Demo', 'edumag-pro' ),
        'category' => esc_html__( 'Category', 'edumag-pro' ),
    ),
) );

// Add Popular articles title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_title]', array(
	'default'           => $options['popular_articles_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_title]', array(
	'label'           	=> esc_html__( 'Title', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'active_callback' 	=> 'edumag_pro_is_demo_content_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[popular_articles_title]', array(
		'selector'            => '#popular-articles h2.entry-title',
		'render_callback'     => 'edumag_pro_customize_partial_popular_articles_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add Popular articles sub title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_subtitle]', array(
	'default'           => $options['popular_articles_subtitle'],
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_subtitle]', array(
	'label'           	=> esc_html__( 'Description', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'type'				=> 'textarea',
	'active_callback' 	=> 'edumag_pro_is_demo_content_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[popular_articles_subtitle]', array(
		'selector'            => '#popular-articles p.sub-title',
		'render_callback'     => 'edumag_pro_customize_partial_popular_articles_subtitle',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add popular articles number of posts setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_no_of_tabs]', array(
	'default'           => $options['popular_articles_no_of_tabs'],
	'sanitize_callback' => 'edumag_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_no_of_tabs]', array(
	'label'           	=> esc_html__( 'Number Of Tabs', 'edumag-pro' ),
	'description'       => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects. Min 1 and Max 5.', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'edumag_pro_is_demo_content_inactive',
	'input_attrs'		=> array(
		'min'			=> '1',
		'max'			=> '5',
		'step'			=> '1',
		'style'			=> 'width:50px',
		),
) );

$no_of_popular_articles = $options['popular_articles_no_of_tabs'];

for( $i=1; $i<=$no_of_popular_articles; $i++ ){
	// Show category type setting and control
	$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_content_category_'. $i .']', array(
		'sanitize_callback' => 'edumag_pro_sanitize_dropdown_category_list'
	) );

	$wp_customize->add_control( new Edumag_Pro_Dropdown_Category_Control( $wp_customize, 'edumag_pro_theme_options[popular_articles_content_category_'. $i .']', array(
		'label'           => sprintf( esc_html__( 'Select Category #%s', 'edumag-pro' ), $i ),
		'description'     => esc_html__( 'Popular posts from selected category will be shown.', 'edumag-pro' ),
		'type'			  => 'dropdown-category',
		'section'         => 'edumag_pro_popular_articles_section',
		'active_callback' => 'edumag_pro_is_demo_content_inactive',
	) ) );
}

// Add Popular articles sub title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_featured_posts_section_title]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Edumag_Pro_Note_Control( $wp_customize, 'edumag_pro_theme_options[popular_articles_featured_posts_section_title]', array(
	'label'           	=> esc_html__( 'Featured Posts Section', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'type'				=> 'description',
	'active_callback' 	=> 'edumag_pro_is_demo_content_inactive',
) ) );

for( $i=1; $i<=2; $i++ ){
	// add featurd posts  setting and control
	$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_featured_post_'. $i .']', array(
		'sanitize_callback' => 'edumag_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_featured_post_'. $i .']', array(
		'label'           => sprintf( esc_html__( 'Post ID #%s', 'edumag-pro' ), $i ),
		'description'     => esc_html__( 'Enter post ID to use it as featured post.', 'edumag-pro' ),
		'section'         => 'edumag_pro_popular_articles_section',
		'type'			  => 'number',
		'active_callback' => 'edumag_pro_is_demo_content_inactive',
	) );
}

// Add Popular articles advertisement title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_featured_advertisement_title]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Edumag_Pro_Note_Control( $wp_customize, 'edumag_pro_theme_options[popular_articles_featured_advertisement_title]', array(
	'label'           	=> esc_html__( 'Advertisement Section', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'type'				=> 'description',
	'active_callback' 	=> 'edumag_pro_is_demo_content_inactive',
) ) );

// Add advertisement section setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_ad_type]', array(
	'default'           => $options['popular_articles_ad_type'],
	'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_ad_type]', array(
	'label'           	=> esc_html__( 'Advertisement Type', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'type'            	=> 'select',
	'choices'         	=> array(
		'disabled' => esc_html__( 'Disabled', 'edumag-pro' ),
		'demo'     => esc_html__( 'Demo', 'edumag-pro' ),
        'ad_image' => esc_html__( 'Advertisement Image', 'edumag-pro' ),
        'ad_code'  => esc_html__( 'Advertisement Code', 'edumag-pro' ),
    ),
) );

// Add advertisement image setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_ad_image]', array(
	'default'           => $options['popular_articles_ad_image'],
	'sanitize_callback' => 'edumag_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'edumag_pro_theme_options[popular_articles_ad_image]',
    array(
		'label'           => esc_html__( 'Upload a Advertisement Image', 'edumag-pro' ),
		'description'     => esc_html__( 'Recommended advertisement image size is 780x90 px', 'edumag-pro' ),
		'section'         => 'edumag_pro_popular_articles_section',
		'active_callback' => 'edumag_pro_is_popular_article_ad_image_active',
   )
));

// Add advertisement link setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_ad_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_ad_url]', array(
	'label'           	=> esc_html__( 'Link', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'type'            	=> 'url',
	'active_callback' 	=> 'edumag_pro_is_popular_article_ad_image_active',
) );

// Add advertisement open in new tab setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_new_tab]', array(
	'sanitize_callback' => 'edumag_pro_sanitize_checkbox',
	'default'			=> $options['popular_articles_new_tab'],
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_new_tab]', array(
	'label'           	=> esc_html__( 'Check to open in new tab.', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_popular_articles_section',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'edumag_pro_is_popular_article_ad_image_active',
) );

// Add advertisement image setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[popular_articles_ad_code]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[popular_articles_ad_code]',
    array(
		'label'           => esc_html__( 'Advertisement Code', 'edumag-pro' ),
		'description'     => esc_html__( 'Enter advertisement code.', 'edumag-pro' ),
		'section'         => 'edumag_pro_popular_articles_section',
		'type'			  => 'textarea',
		'active_callback' => 'edumag_pro_is_popular_article_ad_code_active',
   )
);

