<?php
/**
 * Latest news
 *
 * This is the template for the content of Latest news
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if ( ! function_exists( 'edumag_pro_add_latest_news_section' ) ) :
  /**
   * Add Latest news
   *
   *@since EduMag Pro 1.0
   */

  function edumag_pro_add_latest_news_section() {

    // Check if Search is enabled on frontpage
    $latest_news_enable = apply_filters( 'edumag_pro_section_status', true, 'latest_news_enable' );
    if ( true !== $latest_news_enable ) {
        return false;
    }

    // Get Latest news details
    $section_details = array();
    $section_details = apply_filters( 'edumag_pro_filter_latest_news_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render Latest news now.
    edumag_pro_render_latest_news_section( $section_details );
  }
endif;
add_action( 'edumag_pro_primary_content', 'edumag_pro_add_latest_news_section', 60 );


if ( ! function_exists( 'edumag_pro_get_latest_news_section_details' ) ) :
  /**
   * Latest news details.
   *
   * @since EduMag Pro 1.0
   * @param array $input Latest news details.
   */
  function edumag_pro_get_latest_news_section_details( $input ) {
    $options = edumag_pro_get_theme_options();

    // Search type
    $latest_news_content_type   = $options['latest_news_content_type'];
    
    $content = array();
    switch ( $latest_news_content_type ) {

        case 'demo':
            $tabs = array(
               'all' => array(
                    'value' => 'all-latest-news',
                    'label' => esc_html__( 'All', 'edumag-pro' )
                ),
                'news-college' => array(
                    'value' => 'tab-news-college',
                    'label' => esc_html__( 'College', 'edumag-pro' )
                ),
                'news-careers' => array(
                    'value' => 'tab-news-careers',
                    'label' => esc_html__( 'Careers', 'edumag-pro' )
                ),
                'news-sports' => array(
                    'value' => 'tab-news-sports',
                    'label' => esc_html__( 'Sports', 'edumag-pro' )
                )
            );

            $title_array = array(
                esc_html__( 'Always learn something very beautiful & innovative.', 'edumag-pro' ),
                esc_html__( 'Unusual ways people pay for college', 'edumag-pro' ),
                esc_html__( 'Intoduction to  networking for beginner', 'edumag-pro' ),
                esc_html__( 'How to Prevent Stress While Studying', 'edumag-pro' ),
            );

            foreach ($tabs as $key => $tab ) {               
                $index = 1; 
                for ( $i=1; $i<=11; $i++ ) {

                    if( 4 == $index ){
                        $index = 1;
                    } else {
                        $index ++;
                    }
                    $content[$key][$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/latest-news-0'.$index.'.jpg';
                    $content[$key][$i]['url']          = '#';
                    $content[$key][$i]['title']        = $title_array[$index-1];
                    $content[$key][$i]['excerpt']      = esc_html__( 'Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id eli.', 'edumag-pro' );
                    $content[$key][$i]['cat_array']    = array( $tab['label'] );
                    $content[$key][$i]['date']         = esc_html__( 'Dec 18, 2016', 'edumag-pro' );
                    $content[$key][$i]['likes']        = '<span><i class="fa fa-heart"></i></span>';
                }
            }
        break;

        case 'category':
            $cat_ids = '';
            if ( !empty( $options['latest_news_content_category'] ) ) {
                $cat_ids = $options['latest_news_content_category'];
            }
            
            // Bail if no valid pages are selected.
            if ( empty( $cat_ids ) ) {
                return $input;
            }

            $args = array(
                'post_type'      => 'post',
                'category__in'   => $cat_ids,
                'posts_per_page' => 11,// absint( get_option( 'posts_per_page' ) ),  Maximum number of posts to show on a page; set in Reading Options.,
                'orderby'        => 'ASC',
            );

            $all_posts = get_posts( $args );

            $k = 1;
            foreach ( $all_posts as $key => $post ) {
                $post_id   =  $post->ID;
                $img_array = array();

                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'edumag-pro-featured-popular-article' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
                }

                $like_string =  '';
                if( function_exists( 'tp_education_like_button' ) ){
                    $like_string = tp_education_like_button();
                    $like_string = '<span class="screen-reader-text">' . esc_html__( 'Likes', 'edumag-pro' ) . '</span>' . $like_string;
                }

                $content['all'][$k]['img_array'] = $img_array;
                $content['all'][$k]['url']       = get_permalink( $post_id );
                $content['all'][$k]['title']     = get_the_title( $post_id );
                $content['all'][$k]['excerpt']   = edumag_pro_trim_content( 28, $post  );
                $content['all'][$k]['date']      = get_the_date( '', $post_id );
                $content['all'][$k]['cat_array'] = get_the_category( $post_id );
                $content['all'][$k]['likes']     = $like_string;
            $k++;
            }

            foreach ( $cat_ids as $key => $cat_id ) {
                // Fetch posts.
                $args = array( 
                    'cat'            => absint( $cat_id ),
                    'posts_per_page' => 11,// absint( get_option( 'posts_per_page' ) ), // Maximum number of posts to show on a page; set in Reading Options.,
                    'orderby'        => 'ASC',
                );

                $category_posts = get_posts( $args );

                $i = 1;
                foreach( $category_posts as $category_post ){
                    $post_id   = $category_post->ID;
                    $img_array = array();

                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'edumag-pro-featured-popular-article' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
                    }

                    $like_string =  '';
                    if( function_exists( 'tp_education_like_button' ) ){
                        $like_string = tp_education_like_button();
                        $like_string = '<span class="screen-reader-text">' . esc_html__( 'Likes', 'edumag-pro' ) . '</span>' . $like_string;
                    }

                    $content[$cat_id][$i]['img_array']    = $img_array;
                    $content[$cat_id][$i]['url']          = get_permalink( $post_id );
                    $content[$cat_id][$i]['title']        = get_the_title( $post_id );
                    $content[$cat_id][$i]['excerpt']      = edumag_pro_trim_content( 28, $category_post  );
                    $content[$cat_id][$i]['date']         = get_the_date( '', $post_id );
                    $content[$cat_id][$i]['cat_array']    = get_the_category( $post_id );
                    $content[$cat_id][$i]['likes']        = $like_string;
                $i++;
                }
            }
        break;

        default:
            $content_type = $options['latest_news_content_type'];
            $term_ids = array();

            if( !empty( $options[ 'latest_news_'. $content_type ] ) ){
                $term_ids = $options[ 'latest_news_'. $content_type ];
            }

            // Bail if no valid pages are selected.
            if ( empty( $term_ids ) ) {
                return $input;
            }

            $post_type = get_taxonomy( $content_type );

            $args = array(
                'post_type'      => $post_type->object_type[0],
                'posts_per_page' => 11,// absint( get_option( 'posts_per_page' ) ), // Maximum number of posts to show on a page; set in Reading Options.,
                'tax_query'         => array(
                    array(
                        'taxonomy'  => $content_type,
                        'field'     => 'id',
                        'terms'     => $term_ids
                    )
                ),
                'orderby'        => 'ASC',
            );

            $all_posts = get_posts( $args );

            $k = 1;
            foreach ( $all_posts as $key => $post ) {
                $post_id   =  $post->ID;
                $img_array = array();

                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'edumag-pro-featured-popular-article' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
                }

                $like_string =  '';
                if( function_exists( 'tp_education_like_button' ) ){
                    $like_string = tp_education_like_button();
                    $like_string = '<span class="screen-reader-text">' . esc_html__( 'Likes', 'edumag-pro' ) . '</span>' . $like_string;
                }

                $content['all'][$k]['img_array']    = $img_array;
                $content['all'][$k]['url']          = get_permalink( $post_id );
                $content['all'][$k]['title']        = get_the_title( $post_id );
                $content['all'][$k]['excerpt']      = edumag_pro_trim_content( 28, $post  );
                $content['all'][$k]['date']         = get_the_date( '', $post_id );
                $content['all'][$k]['cat_array']    = get_the_terms( $post_id, $content_type );
                $content['all'][$k]['likes']        = $like_string;
            $k++;
            }

            foreach ( $term_ids as $key => $term_id ) {
                // Fetch posts.
                $args = array( 
                    'post_type'      => $post_type->object_type[0],
                    'posts_per_page' => 11,// absint( get_option( 'posts_per_page' ) ), // Maximum number of posts to show on a page; set in Reading Options.,
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => $content_type,
                            'field'     => 'id',
                            'terms'     => $term_id
                        )
                    ),
                    'orderby'        => 'ASC',
                );

                $category_posts = get_posts( $args );

                $i = 1;
                foreach( $category_posts as $category_post ){
                    $post_id   = $category_post->ID;
                    $img_array = array();

                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'edumag-pro-featured-popular-article' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
                    }

                    $like_string =  '';
                    if( function_exists( 'tp_education_like_button' ) ){
                        $like_string = tp_education_like_button();
                        $like_string = '<span class="screen-reader-text">' . esc_html__( 'Likes', 'edumag-pro' ) . '</span>' . $like_string;
                    }

                    $content[$term_id][$i]['img_array']    = $img_array;
                    $content[$term_id][$i]['url']          = get_permalink( $post_id );
                    $content[$term_id][$i]['title']        = get_the_title( $post_id );
                    $content[$term_id][$i]['excerpt']      = edumag_pro_trim_content( 28, $category_post  );
                    $content[$term_id][$i]['date']         = get_the_date( '', $post_id );
                    $content[$term_id][$i]['cat_array']    = get_the_terms( $post_id, $content_type );
                    $content[$term_id][$i]['likes']        = $like_string;
                $i++;
                }
            }

        break;
    }
    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Latest news content details.
add_filter( 'edumag_pro_filter_latest_news_section_details', 'edumag_pro_get_latest_news_section_details' );


if ( ! function_exists( 'edumag_pro_render_latest_news_section' ) ) :
  /**
   * Start Latest news
   *
   * @return string Search content
   * @since EduMag Pro 1.0
   *
   */
   function edumag_pro_render_latest_news_section( $content_details ) {

    if( empty(  $content_details ) ) return;

        $options                = edumag_pro_get_theme_options(); // get theme options
        $content_type           = $options['latest_news_content_type'];
        $section_title          = $options['latest_news_title'];
        $section_subtitle       = $options['latest_news_subtitle'];
        $sidebar_layout         = edumag_pro_layout();
        $sidebar_disabled_class = !is_active_sidebar( 'latest_news_sidebar' ) ? 'sidebar-disabled' : '';
    ?>
     <section id="latest-news" class="page-section">
        <div class="container">
            <div class="main-content <?php echo esc_attr( $sidebar_disabled_class ); ?>">
            <?php if( !empty( $section_title ) || !empty( $section_subtitle ) ){ ?>
                <header class="entry-header wow fadeInDown" data-wow-delay="0.3s" data-wow-duration="0.3s">
                <?php if( !empty( $section_title ) ){ ?>
                    <h2 class="entry-title"><?php echo esc_html( $section_title ); ?></h2>
                <?php }
                if( !empty( $section_subtitle ) ){ ?>
                    <p class="sub-title"><?php echo esc_html( $section_subtitle ); ?></p>
                <?php } ?>
                </header><!--.entry-header-->
            <?php } ?>
                <div class="entry-content  wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">
                    <div class="tab-section">
                        <ul class="tabs">
                         <?php 
                            if( 'demo' == $content_type ){
                            echo    '<li class="tab-link active" data-tab="all-latest-news"><a href="#.">'. esc_html__( 'all', 'edumag-pro' ) .'</a></li>
                                    <li class="tab-link" data-tab="tab-news-college"><a href="#.">'. esc_html__( 'College', 'edumag-pro' ) .'</a></li>
                                    <li class="tab-link" data-tab="tab-news-careers"><a href="#.">'. esc_html__( 'Careers', 'edumag-pro' ) .'</a></li>
                                    <li class="tab-link" data-tab="tab-news-sports"><a href="#.">'. esc_html__( 'Sports', 'edumag-pro' ) .'</a></li>';
                            } elseif( 'category' == $content_type ) {
                                $cat_ids = array(); 

                                if( !empty( $options['latest_news_content_category'] ) ){
                                    $cat_ids = $options['latest_news_content_category'];
                                }

                                if( !empty( $cat_ids ) ){
                                    echo '<li class="tab-link active" data-tab="all-latest-news"><a href="#.">'. esc_html__( 'all', 'edumag-pro' ) .'</a></li>';
                                    foreach( $cat_ids as $cat ){
                                            $cat_object = get_category( $cat );

                                            $tab_id    = 'tab-news-'. $cat_object->slug;
                                            $tab_name  = get_cat_name( $cat_object->term_id );
                                        
                                            echo '<li class="tab-link" data-tab="'. esc_attr( $tab_id ) .'"><a href="#.">'. esc_html( $tab_name ) .'</a></li>';
                                    }
                                    
                                }
                            } else {
                                $terms_ids = $options['latest_news_'. $content_type ];

                                if( !empty( $terms_ids ) ){
                                    echo '<li class="tab-link active" data-tab="all-latest-news"><a href="#.">'. esc_html__( 'all', 'edumag-pro' ) .'</a></li>';
                                    foreach ( $terms_ids as $key => $terms_id ) {
                                        $term_object = get_term( $terms_id, $content_type, OBJECT );
                                        $tab_id    = 'tab-news-'. $term_object->slug;
                                        $tab_name  = get_cat_name( $term_object->term_id );

                                        echo '<li class="tab-link" data-tab="'. esc_attr( $tab_id ) .'"><a href="#.">'. esc_html( $tab_name ) .'</a></li>';
                                    }
                                }
                            }
                        ?>
                        </ul>
                    </div><!--.tab-section-->

                    <?php 

                    foreach ( $content_details as $key => $content_detail ) :
                
                        if( $key == 'all' ){
                            $section_tab_id       = 'all-latest-news';
                            $section_active_class = 'active';
                        } else {
                            if( 'demo' == $content_type ){
                                $section_tab_id       = 'tab-'. $key;
                                $section_active_class = '';
                            } elseif( 'category' == $content_type ) {
                                $cat_object = get_category( absint( $key ) );
                                $section_tab_id       = 'tab-news-'. $cat_object->slug;
                                $section_active_class = '';
                            } else{
                                $term_object = get_term( $key, $content_type, OBJECT );
                                $section_tab_id       = 'tab-news-'. $term_object->slug;
                                $section_active_class = '';
                            }
                        }

                        $row_class = count( $content_detail ) > 1 ? 'two-columns' : 'one-column';

                    ?>
                    <div id="<?php echo esc_attr( $section_tab_id ); ?>" class="tab-content <?php echo esc_attr( $section_active_class ); ?>">
                        <div class="row <?php echo esc_attr( $row_class ); ?>">

                            <div class="column-wrapper">
                                <?php foreach ( $content_detail as $key => $content ) { ?>
                                <div class="article-wrapper"> 
                                    <div class="image-wrapper">
                                        <a href="<?php echo esc_url( $content['url']); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                        <p class="cat-links">
                                            <?php 
                                                $cat_link = '';
                                                $cat_name = '';
                                                if( 'demo' == $content_type ){

                                                $cat_name = $content['cat_array'][0];
                                                $cat_link = '#';
                                            } elseif ( 'category' == $content_type ){
                                                $cat_array = $content['cat_array'];

                                                foreach ( $cat_array as $key => $category ) {
                                                    $cat_link = get_category_link( $category->term_id );
                                                    $cat_name = $category->name;
                                                }
                                            } else{
                                                $term_array = $content['cat_array'];

                                                foreach ( $term_array as $key => $term ) {
                                                    $cat_link =get_term_link( $term->term_id, $content_type );
                                                    $cat_name = $term->name;
                                                }
                                            }?>
                                            <a href="<?php echo esc_url( $cat_link ); ?>" class="category-name"><?php echo esc_html( $cat_name ); ?></a>
                                        </p><!-- .cat-links -->
                                    </div><!-- end .image-wrapper -->

                                    <div class="article-contents-wrapper">
                                        <?php if( !empty( $content['title'] ) ){ ?>
                                        <div class="article-title">
                                          <h2><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                          <div class="title-bottom-line"></div>
                                        </div><!-- .article-title -->
                                        <?php }
                                        if( !empty( $content['excerpt'] ) ){ ?>

                                        <div class="article-desc">
                                          <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .article-desc -->
                                        <?php } ?>

                                        <div class="article-entry-meta">
                                            <div class="pull-left">
                                                <time><?php echo date_i18n( esc_html__( 'M d, Y', 'edumag-pro' ), strtotime( $content['date'] ) ); ?></time>
                                            </div><!--.pull-left-->

                                          <div class="pull-right">
                                            <?php 
                                                if( !empty( $content['likes'] ) ){
                                                    echo wp_kses_post( $content['likes'] );
                                                }
                                            ?>
                                            </div><!--.pull-right-->
                                        </div><!-- .article-entry-meta -->

                                    </div><!-- end .article-contents-wrapper -->
                                </div><!-- .article-wrapper -->

                                <?php 
                                break;
                                }; ?>
                            </div><!-- .column-wrapper -->

                            <?php 
                                $content_detail =  array_splice( $content_detail,1, count( $content_detail ) ); // remove first content element from array
                            if( !empty( $content_detail ) ) : ?>
                            <div class="column-wrapper">
                                <div class="regular widget widget_popular_views" data-slick="{"slidesToShow":1, "slidesToScroll":1, "infinite":false, "speed":800, "dots":false, "arrows":true, "autoplay":true, "fade":false, "draggable":false }">

                                    <div class="slider-item">
                                        <ul>
                                            <?php
                                                $index = 1;                  
                                                $count = count( $content_detail );
                                                foreach ( $content_detail as $key => $content ) { ?>
                                                <li class="has-post-thumbnail">
                                                    <div class="image-wrapper">
                                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] );?>"></a>
                                                    </div><!-- end .image-wrapper -->

                                                    <div class="article-contents-wrapper">
                                                        <?php if( !empty( $content['title'] ) ){ ?>
                                                        <div class="article-title">
                                                            <h2><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                                        </div><!-- .article-title -->
                                                        <?php } ?>
                                                        <div class="article-entry-meta">
                                                            <time><?php echo date_i18n( esc_html__( 'M d, Y', 'edumag-pro' ), strtotime( $content['date'] ) ); ?></time>
                                                        </div><!-- .article-desc -->
                                                    </div><!-- .articles-contents-wrapper -->
                                                </li>
                                            <?php 
                                            if( $count > 5 ) {
                                                $diviser = 5;
                                            } else {
                                                $diviser = $count;
                                            }

                                            if( ( $index % $diviser == 0 ) ){
                                                if( $count == $index  ){ 
                                                    echo '</ul></div><!-- .slider-item -->';
                                                }
                                                else {
                                                    echo  '</ul></div><div class="slider-item"><ul>';
                                                }
                                            }                                            
                                            $index++;
                                        }
                                        $search_array = array( 7,8,9,10 );
                                        if( in_array( $index, $search_array ) ){
                                            echo '</ul></div><!-- .slider-item -->';
                                        }?>                         
                                </div><!-- .regular -->
                            </div><!-- .column-wrapper -->
                            <?php endif; ?>
                        </div><!-- .two-columns -->
                    </div><!-- #tab-all-news -->
                    <?php endforeach; ?>
              
                </div><!--.entry-content-->
            </div><!--.main-content-->

            <?php if( is_active_sidebar( 'latest_news_sidebar' ) && ( 'no-sidebar' != $sidebar_layout ) ) : ?>
            <div class="section-sidebar">
                <?php dynamic_sidebar( 'latest_news_sidebar' ); ?>
            </div><!-- .section-sidebar -->
            <?php endif; ?>
        </div><!-- .container -->
    </section><!-- #latest-news -->
    <?php 
    }
endif;