<?php
/**
 * Search section
 *
 * This is the template for the content of Search section
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */
if ( ! function_exists( 'edumag_pro_add_search_section' ) ) :
  /**
   * Add Search section
   *
   *@since EduMag Pro 1.0
   */
  function edumag_pro_add_search_section() {

    // Check if Search is enabled on frontpage
    $search_section_enable = apply_filters( 'edumag_pro_section_status', true, 'search_section_enable' );
    if ( true !== $search_section_enable ) {
      return false;
    }

    $options = edumag_pro_get_theme_options(); // get theme mods
    // Render Search section now.
    edumag_pro_render_search_section( $options );
  }
endif;
add_action( 'edumag_pro_primary_content', 'edumag_pro_add_search_section', 30 );

if ( ! function_exists( 'edumag_pro_render_search_section' ) ) :
  /**
   * Start Search section
   *
   * @return string Search content
   * @since EduMag Pro 1.0
   *
   */

   function edumag_pro_render_search_section( $options ) {
        $background_image          = !empty( $options['search_section_background_image'] ) ? $options['search_section_background_image'] : '';
        $background_image_property = !empty( $background_image ) ? 'background-image: url('. $background_image .');': '';
        $search_title              = !empty( $options['search_section_title'] ) ? $options['search_section_title'] : '';
        $search_subtitle           = !empty( $options['search_section_subtitle'] ) ? $options['search_section_subtitle'] : '';
        $search_custom_post_type   = ( 'custom-posts' == $options['search_section_search_in'] ) && !empty( $options['search_section_custom_post'] ) ? $options['search_section_custom_post'] : 'post';
        $search_button_text        = !empty( $options['search_section_button_text'] ) ? $options['search_section_button_text'] : esc_html__( 'Search', 'edumag-pro' );
    ?>
    <section id="fixed-background" class="page-section wow fadeInDown" data-wow-delay="0.3s" data-wow-duration="0.3s" style="<?php echo esc_attr( $background_image_property ); ?>">
        <div class="blue-overlay"></div>
        <div class="container">
            <?php if( !empty( $search_title ) || !empty( $search_subtitle ) ) : ?>
            <header class="entry-header wow fadeInUp" data-wow-delay="0.2s" data-wow-duration="0.5s">
                <?php if( !empty( $search_title ) ){ ?>
                <h2 class="entry-title"><?php echo esc_html( $search_title ); ?></h2>
                <?php } 
                if( !empty( $search_subtitle ) ) { ?>
                <p class="sub-title"><?php echo esc_html( $search_subtitle ); ?></p>
                <?php } ?>
            </header><!--.entry-header-->
            <?php endif; ?>

            <div class="entry-content wow fadeInUp" data-wow-delay="0.2s" data-wow-duration="0.5s">
                <form action="<?php echo esc_url( home_url('/') ); ?>" role="search" method="get" >
                    <input type="text" name="s">
                    <input type="hidden" name="section" value="search-section" >
                    <input type="hidden" name="post_type" value="<?php echo esc_attr( $search_custom_post_type ); ?>" />
                    <i class="fa fa-search"></i>
                    <button type="submit" class="btn btn-orange"><?php echo esc_html( $search_button_text ); ?></button>
                </form>
            </div><!--.entry-content-->
        </div><!--.container-->
    </section><!--.fixed-background-->
    <?php 
    }
endif;