<?php
/**
 * Theme_Palace options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if( !function_exists( 'edumag_pro_header_typography_options' ) ) :
    /**
     * Returns list of header typography
     * @return array header font styles
     */
    function edumag_pro_header_typography_options(){

        $choices = array(
          'default'       => esc_html__( 'Default', 'edumag-pro' ),
          'header-font-1' => esc_html__( 'Rajdhani Font', 'edumag-pro' ),
          'header-font-2' => esc_html__( 'Cherry Swash', 'edumag-pro' ),
          'header-font-3' => esc_html__( 'Philosopher Font', 'edumag-pro' ),
          'header-font-4' => esc_html__( 'Slabo Font', 'edumag-pro' ),
          'header-font-5' => esc_html__( 'Dosis Font', 'edumag-pro' )
        );
        $output = apply_filters( 'edumag_pro_header_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }
        return $output;
    }
endif;

if( !function_exists( 'edumag_pro_body_typography_options' ) ) :
    /**
     * Returns list of header typography
     * @return array header font styles
     */
    function edumag_pro_body_typography_options(){

        $choices = array(
          'default'     => esc_html__( 'Default', 'edumag-pro' ),
          'body-font-1' => esc_html__( 'News Cycle Font', 'edumag-pro' ),
          'body-font-2' => esc_html__( 'Pontano Sans Font', 'edumag-pro' ),
          'body-font-3' => esc_html__( 'Gudea Font', 'edumag-pro' ),
          'body-font-4' => esc_html__( 'Quattrocento Font', 'edumag-pro' ),
          'body-font-5' => esc_html__( 'Khand Font', 'edumag-pro' )
        );
        $output = apply_filters( 'edumag_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }
        return $output;

    }
endif;

if( !function_exists( 'edumag_pro_enable_disable_options' ) ) :
    /**
     * Section enable/disable options
     * @return array enable/disable options
     */
    function edumag_pro_enable_disable_options() {
      $edumag_pro_enable_disable_options = array(
        'static-frontpage'  => esc_html__( 'Static Frontpage', 'edumag-pro' ),
        'disabled'          => esc_html__( 'Disabled', 'edumag-pro' ),
      );

      $output = apply_filters( 'edumag_pro_enable_disable_options', $edumag_pro_enable_disable_options );
      
      if ( ! empty( $output ) ) {
        ksort( $output );
      }

      return $output;
    }
endif;

if( !function_exists( 'edumag_pro_theme_color' ) ) :
    /**
     * Theme Color
     * @return array site theme color options
     */
    function edumag_pro_theme_color() {
      $edumag_pro_theme_color = array(
        'blue'   => esc_html__( 'Blue', 'edumag-pro' ),
        'red'    => esc_html__( 'Red', 'edumag-pro' ),
        'green'  => esc_html__( 'Green', 'edumag-pro' ),
        'yellow' => esc_html__( 'Yellow', 'edumag-pro' ),
        'black'  => esc_html__( 'Black', 'edumag-pro' )
      );

      $output = apply_filters( 'edumag_pro_theme_color', $edumag_pro_theme_color );

      return $output;
    }
endif;

if( !function_exists( 'edumag_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function edumag_pro_site_layout() {
      $edumag_pro_site_layout = array(
        'wide'  => esc_html__( 'Wide', 'edumag-pro' ),
        'boxed' => esc_html__( 'Boxed', 'edumag-pro' ),
      );

      $output = apply_filters( 'edumag_pro_site_layout', $edumag_pro_site_layout );

      return $output;
    }
endif;

if( !function_exists( 'edumag_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function edumag_pro_sidebar_position() {
      $edumag_pro_sidebar_position = array(
        'right-sidebar' => esc_html__( 'Right', 'edumag-pro' ),
        'left-sidebar'  => esc_html__( 'Left', 'edumag-pro' ),
        'no-sidebar'    => esc_html__( 'No Sidebar', 'edumag-pro' ),
      );

      $output = apply_filters( 'edumag_pro_sidebar_position', $edumag_pro_sidebar_position );

      return $output;
    }
endif;

if( !function_exists( 'edumag_pro_selected_sidebar' ) ) :
    /**
     * Selected sidebar
     * @return array available Sidbar
     */
    function edumag_pro_selected_sidebar() {
      $edumag_pro_selected_sidebar = array(
        'sidebar-1'          => esc_html__( 'Default ( Primary Sidebar )', 'edumag-pro' ),
        'front_page_sidebar' => esc_html__( 'Front Page Sidebar', 'edumag-pro' ),
        'optional_sidebar_1' => esc_html__( 'Optional Sidebar 1', 'edumag-pro' ),
        'optional_sidebar_2' => esc_html__( 'Optional Sidebar 2', 'edumag-pro' ),
      );

      $output = apply_filters( 'edumag_pro_selected_sidebar', $edumag_pro_selected_sidebar );

      return $output;
    }
endif;

if( !function_exists( 'edumag_pro_header_image' ) ) :
    /**
     * Header image options
     * @return array Header image options
     */
    function edumag_pro_header_image() {
      $edumag_pro_header_image = array(
        'enable' => esc_html__( 'Enable( Featured Image )', 'edumag-pro' ),
        '' => esc_html__( 'Default ( Customizer Header Image )', 'edumag-pro' ),
        'disable'  => esc_html__( 'Disable', 'edumag-pro' ),
      );

      $output = apply_filters( 'edumag_pro_header_image', $edumag_pro_header_image );

      return $output;
    }
endif;

if( !function_exists( 'edumag_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function edumag_pro_pagination_options() {
      $edumag_pro_pagination_options = array(
        'numeric'         => esc_html__( 'Numeric', 'edumag-pro' ),
        'default'         => esc_html__( 'Default(Older/Newer)', 'edumag-pro' ),
        'infinite-click'  => esc_html__( 'Infinite Click (Jetpack)', 'edumag-pro' ),
        'infinite-scroll' => esc_html__( 'Infinite Scroll (Jetpack)', 'edumag-pro' )
      );

      $output = apply_filters( 'edumag_pro_pagination_options', $edumag_pro_pagination_options );

      return $output;
    }
endif;

if( !function_exists( 'edumag_pro_information_taxonomy_content_type' ) ) :
    /**
     * Category and Taxonomy content types
     * @return array Content types
     */
    function edumag_pro_information_taxonomy_content_type() {
      $edumag_pro_information_taxonomy_content_type = array(
        'demo'      => esc_html__( 'Demo', 'edumag-pro' ),
        'category'  => esc_html__( 'Category', 'edumag-pro' ),
      ); 

      $taxonomies = get_taxonomies( array( '_builtin' => false ) , 'objects' );
      if ( count( $taxonomies ) > 0 ) {
        foreach ( $taxonomies as $taxonomy ) :
          $edumag_pro_information_taxonomy_content_type = array_merge( $edumag_pro_information_taxonomy_content_type, array( $taxonomy->name => $taxonomy->labels->name ) );
        endforeach;
      }

      $output = apply_filters( 'edumag_pro_information_taxonomy_content_type', $edumag_pro_information_taxonomy_content_type );

      return $output;
    }
endif;
