<?php
/**
 * Travel Resources Widget
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if ( ! class_exists( 'Edumag_Pro_Custom_Travel_Resources_Widget' ) ) :
	/**
	 * Travel Resources class.
	 *
	 * @since EduMag Pro 1.0
	 */
	class Edumag_Pro_Custom_Travel_Resources_Widget extends WP_Widget {
		/**
		 * Sets up the widgets name etc
		 */
		public function __construct() {
			$widget_ops = array(
				'classname'   => 'widget_travel_resources',
				'description' => esc_html__( 'Widget with additional features to display travel resources.', 'edumag-pro' ),
			);
			parent::__construct( 'widget_travel_resources',esc_html__('TP : Travel Resources','edumag-pro'), $widget_ops );
		}

		/**
		 * Outputs the content of the widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {
			// outputs the content of the widget
			if ( ! isset( $args['widget_id'] ) ) {
				$args['widget_id'] = $this->id;
			}

			$title 	= ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Stay Connected', 'edumag-pro' );

			$open_link  = ! empty( $instance['open_link'] ) ? true : false;
			$target = ( empty( $open_link ) ) ? '' : 'target=_blank';


			echo $args['before_widget'];
				if ( ! empty( $title ) ) {
					echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
				}
			$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
			$open_link = ! empty( $instance['open_link'] ) ? true : false;
			$target    = ( empty( $open_link ) ) ? '' : 'target=_blank';  ?>

			<ul>
			<?php
				for ( $i=1; $i <= $number ; $i++ ) {
					$resource_icon  = ( ! empty( $instance['resource_icon_' . $i] ) ) ? $instance['resource_icon_' . $i] : '';
					$resource_title = ( ! empty( $instance['resource_title_' . $i] ) ) ? $instance['resource_title_' . $i] : ''; 
					$resource_link  = ( ! empty( $instance['resource_link_' . $i] ) ) ? $instance['resource_link_' . $i] : '#'; 
			?>
              	<li>
              		<?php if( !empty( $resource_icon ) ) : ?>
                	<div class="icon">
                  		<i class="fa <?php echo esc_attr( $resource_icon ); ?>"></i>
                	</div><!-- .icon -->
                	<?php endif;

                	if( !empty( $resource_title ) ) : ?>
                	<div class="travel-resource">
                  		<a href="<?php echo esc_url( $resource_link ) . '" ' . esc_attr( $target ); ?>"><?php echo esc_html( $resource_title ); ?></a>
                	</div><!-- .travel-resource -->
                	<?php endif; ?>
              	</li>
              	<?php } ?>
            </ul>
            <button class="slide-down"><i class="fa fa-angle-down"></i></button>
			<?php
			echo $args['after_widget'];
		}

		/**
		 * Outputs the options form on admin
		 *
		 * @param array $instance The widget options
		 */
		public function form( $instance ) {
			$title     	= isset( $instance['title'] ) ? ( $instance['title'] ) : esc_html__( 'Stay Connected', 'edumag-pro' );
			$number 	= isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
			$open_link 	= isset( $instance['open_link'] ) ? $instance['open_link'] : false;
		   ?>

		    <p>
			   <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'edumag-pro' ); ?></label>
			   <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		    </p>

		    <p>
		   		<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of Resources to show:', 'edumag-pro' ); ?></label>
		   		<input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" max="6" value="<?php echo absint( $number ); ?>" size="3" />
		    </p>

		   <?php for ( $i=1; $i <= $number; $i++ ) {
				$resource_icon  = isset( $instance['resource_icon_' . $i ] ) ? $instance['resource_icon_' . $i ] : '';
				$resource_title = isset( $instance['resource_title_' . $i ] ) ? $instance['resource_title_' . $i ] : '';
				$resource_link  = isset( $instance['resource_link_' . $i ] ) ? $instance['resource_link_' . $i ] : '#';
			?>
				<hr style="width: 100%"/>
				<p>
			   		<label for="<?php echo esc_attr( $this->get_field_id( 'resource_icon_' . $i ) ); ?>"><?php printf( esc_html__( 'Icon %s :', 'edumag-pro' ), $i ); ?></label>
			   		<input type="text" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'resource_icon_' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'resource_icon_' . $i ) ); ?>" value="<?php echo esc_attr( $resource_icon ); ?>" placeholder="<?php echo esc_attr( 'fa-plane' ); ?>"/>
			    </p>

			    <p>
			   		<label for="<?php echo esc_attr( $this->get_field_id( 'resource_title_' . $i ) ); ?>"><?php printf( esc_html__( 'Title %s :', 'edumag-pro' ), $i ); ?></label>
			   		<input type="text" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'resource_title_' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'resource_title_' . $i ) ); ?>" value="<?php echo esc_attr( $resource_title ); ?>" placeholder="<?php echo esc_attr( 'Enter title here.' ); ?>"/>
			    </p>

			    <p>
			   		<label for="<?php echo esc_attr( $this->get_field_id( 'resource_link_' . $i ) ); ?>"><?php printf( esc_html__( 'Link %s :', 'edumag-pro' ), $i ); ?></label>
			   		<input type="url" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'resource_link_' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'resource_link_' . $i ) ); ?>" value="<?php echo esc_url( $resource_link ); ?>" placeholder="#"/>
			    </p>
		   <?php }?>

		   <p>
		      <label for="<?php echo esc_attr( $this->get_field_id( 'open_link' ) ); ?>"><?php esc_html_e( 'Open in New Tab', 'edumag-pro' ); ?>:</label>
		      <input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'open_link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'open_link' ), 'edumag-pro' ); ?>"  <?php checked( $open_link, true ); ?> />
		    </p>

		   <?php
		}

		/**
		* Processing widget options on save
		*
		* @param array $new_instance The new options
		* @param array $old_instance The previous options
		*/
		public function update( $new_instance, $old_instance ) {
			// processes widget options to be saved
			$instance           			= $old_instance;
			$instance['title']  			= sanitize_text_field( $new_instance['title'] );
			$instance['number'] 			= absint( $new_instance['number'] );
			$instance['open_link']       	= edumag_pro_sanitize_checkbox( $new_instance['open_link'] );
			for ( $i=1; $i <= $instance['number']; $i++ ) {
				$instance['resource_icon_' . $i]  = sanitize_text_field( $new_instance['resource_icon_' . $i] );
				$instance['resource_title_' . $i] = sanitize_text_field( $new_instance['resource_title_' . $i] );
				$instance['resource_link_' . $i]  = esc_url_raw( $new_instance['resource_link_' . $i] );
			}
			return $instance;
		}
	}
endif;

function edumag_pro_travel_resources_widget() {
	register_widget( 'Edumag_Pro_Custom_Travel_Resources_Widget' );
}
add_action( 'widgets_init', 'edumag_pro_travel_resources_widget' );